#
# spec file for package slick-greeter
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   lightdm-slick-greeter
Name:           slick-greeter
Version:        1.5.2
Release:        bp156.3.6
Summary:        The slick-looking login screen application
License:        GPL-3.0-only AND CC-BY-SA-3.0
Group:          System/X11/Displaymanagers
URL:            https://github.com/linuxmint/slick-greeter
Source:         https://github.com/linuxmint/slick-greeter/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source1:        README.GSettings-overrides
# PATCH-FEATURE-OPENSUSE slick-greeter-gtk-3.20.patch -- Restore GTK+ 3.20 support.
Patch0:         slick-greeter-gtk-3.20.patch
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.24
BuildRequires:  pkgconfig(cairo-ft)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(liblightdm-gobject-1) >= 1.12.0
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)

%description
The slick-looking greeter (login screen) application.
It is implemented as a LightDM greeter.

%package -n %{_name}
Summary:        The slick-looking login screen application
Group:          System/X11/Displaymanagers
Requires:       lightdm
Requires:       numlockx
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{_name}-lang
Provides:       lightdm-greeter
%glib2_gsettings_schema_requires

%description -n %{_name}
The slick-looking greeter (login screen) application.
It is implemented as a LightDM greeter.

%lang_package -n %{_name}

%package -n %{_name}-branding-upstream
Summary:        Upstream branding of %{_name}
Group:          System/X11/Displaymanagers
Requires:       %{_name} = %{version}
Requires:       gnome-icon-theme
Requires:       gtk3-metatheme-adwaita
Requires:       ubuntu-fonts
Supplements:    packageand(%{_name}:branding-upstream)
Conflicts:      otherproviders(%{_name}-branding)
Provides:       %{_name}-branding = %{version}
BuildArch:      noarch
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.GSettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description -n %{_name}-branding-upstream
This package provides the upstream look and feel for
lightdm-slick-greeter.

%prep
%setup -q
cp -a %{SOURCE1} .
%patch0 -p1

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}

%if 0%{?suse_version} >= 1320
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/lightdm-default-greeter.desktop
ln -s %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop \
  %{buildroot}%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif

%post -n %{_name}
update-alternatives --install \
  %{_datadir}/xgreeters/lightdm-default-greeter.desktop \
  lightdm-default-greeter.desktop \
  %{_datadir}/xgreeters/%{name}.desktop \
  10
%if 0%{?suse_version} < 1500
%glib2_gsettings_schema_post
%endif

%postun -n %{_name}
if [ "$1" = 0 ]; then
    update-alternatives --remove \
      lightdm-default-greeter.desktop \
      %{_datadir}/xgreeters/%{name}.desktop
fi
%if 0%{?suse_version} < 1500
%glib2_gsettings_schema_postun
%endif

%files -n %{_name}
%license COPYING
%doc README.md
%{_sbindir}/%{name}
%{_bindir}/%{name}-set-keyboard-layout
%{_bindir}/%{name}-check-hidpi
%{_datadir}/%{name}/
%dir %{_datadir}/xgreeters/
%{_datadir}/xgreeters/%{name}.desktop
%if 0%{?suse_version} >= 1320
%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%else
%ghost %attr(0644,root,root) %{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml
%{_mandir}/man8/%{name}.8%{?ext_man}
%{_mandir}/man1/%{name}-set-keyboard-layout.1%{?ext_man}
%{_mandir}/man1/%{name}-check-hidpi.1%{?ext_man}

%files -n %{_name}-lang -f %{name}.lang

%files -n %{_name}-branding-upstream
%doc README.GSettings-overrides

%changelog
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Update to version 1.5.2.
  * Add badge for fynedesk (#174)
  * l10n: Update translations
* Sun Dec 27 2020 andy great <andythe_great@pm.me>
- Update to version 1.5.1.
  * l10n: Update translations
* Mon Dec  7 2020 andy great <andythe_great@pm.me>
- Update to version 1.5.0.
  * Add clock-format to config.
* Sun Sep 27 2020 andy great <andythe_great@pm.me>
- Update to version 1.4.1.
  * Fix vala-0.45 compile error
  * Add sway badge.
  * l10n: Update translations
  * settings: Turn the 'grid' display off by default.
  * Fix sway badge size
  * Cleaned up and fixed compiler warnings.
  * Finally get the size of the svg right.
  * Remove at-spi load/kill code
  * Add option to span background across multiple monitors
  * Rename/simplify background mode
- Remove vala-0.46.1+-requiring-non-public-creation-method-of-abstract-class.patch
  It was fixed.
- Rebase slick-greeter-gtk-3.20.patch
* Tue Oct 29 2019 Marguerite Su <i@marguerite.su>
- Update to version 1.2.7
  * translation updates
- add vala-0.46.1+-requiring-non-public-creation-method-of-abstract-class.patch
  * vala 0.46.1+ doesn't allow creation method of abstract class
    to be public
* Mon Jul  8 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.2.5:
  * Packaging: Fix Debian build (#122)
  * remove mlockall (#127)
  * Remove slick-greeter-1.2.4-FTBFS-vala-0.43.patch -- Fix Upstream FTBFS with vala 0.43 (#131)
  * Fixed default session for manual user entry. (#129)
* Mon May 27 2019 Marguerite Su <i@marguerite.su>
- fix tumbleweed build
  * add slick-greeter-1.2.4-FTBFS-vala-0.43.patch
* Fri Dec 14 2018 sor.alexei@meowr.ru
- Update to version 1.2.4:
  * Update translations.
* Fri Nov 30 2018 sor.alexei@meowr.ru
- Update to version 1.2.3:
  * background.vala: Fix build with vala 0.42 (no default value
    allowed when using custom getter).
  * Update translations.
- Remove slick-greeter-fix-vala-0.42.patch: fixed upstream.
* Thu Oct 25 2018 sor.alexei@meowr.ru
- Add slick-greeter-fix-vala-0.42.patch: Fix build with Vala 0.42
  (no default value allowed when using custom getter,
  commit ed52e2b).
- Add slick-greeter-gtk-3.20.patch: Restore GTK+ 3.20 support.
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Update translations.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Fix background if the image file is not readable.
  * Update translations.
* Thu May 10 2018 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Add support for numlockx - updated README.
  * slick-greeter.vala: Clear the AT_SPI_BUS property on the root
    window on exit, so the user session components won't fail to
    connect.
  * greeter: Avoid expensive Python calls when it isn't needed.
  * Silence GTK+ 3.22 warnings relating to deprecation in Gdk.Screen.
  * Add an option to show GUI on a specific monitor.
  * Fix HiDPI auto-detection.
* Fri Dec 29 2017 sor.alexei@meowr.ru
- Update to version 1.1.4:
  * Fix build with vala >= 0.39.
* Fri Dec  1 2017 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * main-window: Calculate the really needed screen size properly.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.1.2:
  * Update translations.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 1.1.1:
  * Settings: Reset config keys to default if not in config file.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.1.0:
  * Update translations.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 1.0.9:
  * Remove a broken symlink.
  * Session detection: Add support for more DE/WM.
  * Add tooltips to applets.
  * Add support for numlockx.
  * Rename background-logo -> other-monitors-logo.
  * Other monitors logo: Use full opacity.
  * Make panel indicators optional.
  * Fix compilation warnings.
  * Remove idle_timeout.
  * Add a GNOME 3.26 X.org session and an Ubuntu X.org equivalent
    session.
  * Update translations.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 1.0.8:
  * Kill onboard and orca on session startup.
* Fri Jun 16 2017 sor.alexei@meowr.ru
- Update to version 1.0.7:
  * Badges: Don't hardcode any logic related to badge names.
  * Badges: Prefer SVG over PNG.
  * badges: Convert some badges to svg.
  * Describe options in the README and the man page.
  * badges: more svg converts.
  * Add plasma to the list of default sessions.
  * A11y: Fix HighContrast option.
  * Remove condescending comment in the code.
  * Explicitly set the keyboard layout.
  * Increase onscreen keyboard height.
  * Make error text bold and yellow.
* Fri Jun  9 2017 sor.alexei@meowr.ru
- Update to version 1.0.6 (changes since 1.0.4):
  * backgrounds: Fix determination of what to display as a
    background.
  * Fix prompt display in GTK+ 3.20 or newer.
  * Background: If no user background is set/used, fallback to the
    system background.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Handle errors from liblightdm.
  * dash-entry.vala: Improve position of the hint text draw in the
    password entry box - it should be more centred now instead of
    in the upper left corner.
  * prompt-box.vala: Remove custom allocation code - everything
    works correctly without it. With it, entries are often under-
    or over- allocated, with the result being the active user's
    password entry sometimes does not have enough room to be visible.
  * background: Don't realize() this immediately - only start the
    image gathering thread during initialisation. Wait for the main
    window to be realised before passing its cairo surface to the
    background object and drawing the background for the first time.
  * slick-greeter.vala: Disconnect the event filter when the main
    window is destroyed, otherwise we can continue to receive
    events on the filter when we no longer have a backing GdkWindow
    to act upon (causing a segfault).
* Sat May 20 2017 sor.alexei@meowr.ru
- Update to version 1.0.3:
  * Add greeter icon support for budgie-desktop.
  * Remove some Unity elements from the man page.
  * Add missing man pages.
* Sun May 14 2017 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Fix session validation (gh#linuxmint/slick-greeter#25).
  * Session validation: Refactor in case the variable is null.
  * Update translations.
* Thu May  4 2017 sor.alexei@meowr.ru
- Initial package.
